@@ -38,8 +38,8 @@
 (defvar shimbun-mainichi-url "http://www.mainichi.co.jp/")
 (defvar shimbun-mainichi-server-name "$BKhF|?7J9(B")
 (defvar shimbun-mainichi-from-address  "webmaster@mainichi.co.jp")
-(defvar shimbun-mainichi-content-start "\n<font class=\"news-text\">\n")
-(defvar shimbun-mainichi-content-end  "\n</font>\n")
+(defvar shimbun-mainichi-content-start "<font[\t\n ]+class=\"news-text\">")
+(defvar shimbun-mainichi-content-end  "\\(<br>[\t\n ]*\\)?</font>")
 
 (defvar shimbun-mainichi-group-table
   '(("shakai" "$B<R2qLL(B" "news/flash/shakai")
@@ -140,9 +140,16 @@
 (luna-define-method shimbun-make-contents :before ((shimbun shimbun-mainichi)
 						   header)
   (let ((case-fold-search t))
+    (while (search-forward "\r" nil t)
+      (delete-region (match-beginning 0) (match-end 0)))
     (shimbun-mainichi-remove-tags "<SCRIPT" "</SCRIPT>")
     (shimbun-mainichi-remove-tags "<NOSCRIPT" "</NOSCRIPT>")
     (shimbun-mainichi-remove-tags "<NOEMBED" "</NOEMBED>")
+    (shimbun-mainichi-remove-tags "<table" "</table>")
+    (goto-char (point-min))
+    (while (re-search-forward
+	    "[\t\n ]*<br>[\t\n ]*\\(<!--AdSpace-->[\t\n ]*\\)+" nil t)
+      (delete-region (match-beginning 0) (match-end 0)))
     (goto-char (point-min))
     (when (re-search-forward "<p>$B!NKhF|?7J9#1(B?[$B#0(B-$B#9(B]$B7n(B[$B#1(B-$B#3(B]?[$B#0(B-$B#9(B]$BF|!O(B\
  +( \\(20[0-9][0-9]\\)-\\([01][0-9]\\)-\\([0-3][0-9]\\)-\
